enaml.stdlib
============

The :py:mod:`enaml.stdlib` package contains the standard library built around
the widgets and core functionnalities.

:mod:`fields` Module
--------------------

The following fields all inherit from Field, and do the appropriate type
of validation:

.. autoenaml_decl:: enaml.stdlib.fields.IntField
.. autoenaml_decl:: enaml.stdlib.fields.FloatField
.. autoenaml_decl:: enaml.stdlib.fields.RegexField

:mod:`sessions` Module
----------------------

.. automodule:: enaml.stdlib.sessions
